@@ -1,4 +1,4 @@
-quadFuncDeriv <- function( xNames, data, allCoef, allCoefCov = NULL,
+quadFuncDeriv <- function( xNames, data, coef, coefCov = NULL,
    quadHalf = TRUE ) {
 
    checkNames( c( xNames ), names( data ) )
@@ -8,13 +8,13 @@ quadFuncDeriv <- function( xNames, data, allCoef, allCoefCov = NULL,
    nExog <- length( xNames )
    nCoef <- 1 + nExog + nExog * ( nExog + 1 ) / 2
 
-   if( nCoef != length( allCoef ) ) {
+   if( nCoef != length( coef ) ) {
       stop( "a quadratic function with ", nExog, " exogenous variables",
          " must have exactly ", nCoef, " coefficients" )
    }
 
-   alpha  <- allCoef[ 2:( nExog + 1 ) ]
-   beta   <- vecli2m( allCoef[ ( nExog + 2 ):nCoef ] )
+   alpha  <- coef[ 2:( nExog + 1 ) ]
+   beta   <- vecli2m( coef[ ( nExog + 2 ):nCoef ] )
 
    ## derivatives
    deriv <- array( NA, c( nrow( data ), nExog ) )
@@ -28,21 +28,21 @@ quadFuncDeriv <- function( xNames, data, allCoef, allCoefCov = NULL,
    colnames( deriv ) <- xNames
    result$deriv    <- as.data.frame( deriv )
 
-   if( !is.null( allCoefCov ) ) {
+   if( !is.null( coefCov ) ) {
       ## variances of the derivatives
       variance <- array( NA, c( nrow( data ), nExog ) )
       for(i in 1:nExog ) {
-         variance[ , i ] <- allCoefCov[ i + 1, i + 1 ]   # variance of aplha(i)
+         variance[ , i ] <- coefCov[ i + 1, i + 1 ]   # variance of aplha(i)
          for( j in 1:nExog ) {
             variance[ , i ] <- variance[ , i ] +
-               allCoefCov[ i + 1, 1 + nExog + veclipos( i, j, nExog ) ] *
+               coefCov[ i + 1, 1 + nExog + veclipos( i, j, nExog ) ] *
                ifelse( quadHalf, 1, 2 ) * data[[ xNames[ j ] ]]
                # covariance alpha(i)-beta(i,_)
          }
          for( j in 1:nExog ) {
             for( k in 1:nExog ) {
                variance[ , i ] <- variance[ , i ] +
-                  allCoefCov[ 1 + nExog + veclipos( i, j, nExog ),
+                  coefCov[ 1 + nExog + veclipos( i, j, nExog ),
                   1 + nExog + veclipos( i, k, nExog ) ] *
                   ifelse( quadHalf, 1, 4 ) *
                   data[[ xNames[ j ] ]] * data[[ xNames[ k ] ]]
